@@ -86,7 +86,7 @@
 #define KXMLGUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KXMLGUI_NO_DEPRECATED
-#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54d00
+#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55000
 #endif
 #ifdef KXMLGUI_NO_DEPRECATED_WARNINGS
 #  define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KXMLGUI_DEPRECATED_WARNINGS_SINCE KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0x54d00
+#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0x55000
 #  endif
 #endif
 
